# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'all_paragraphs': 'list[DocxParagraph]',
        'all_tables': 'list[DocxTable]'
    }

    attribute_map = {
        'path': 'Path',
        'all_paragraphs': 'AllParagraphs',
        'all_tables': 'AllTables'
    }

    def __init__(self, path=None, all_paragraphs=None, all_tables=None):  # noqa: E501
        """DocxBody - a model defined in Swagger"""  # noqa: E501

        self._path = None
        self._all_paragraphs = None
        self._all_tables = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if all_paragraphs is not None:
            self.all_paragraphs = all_paragraphs
        if all_tables is not None:
            self.all_tables = all_tables

    @property
    def path(self):
        """Gets the path of this DocxBody.  # noqa: E501

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :return: The path of this DocxBody.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxBody.

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :param path: The path of this DocxBody.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def all_paragraphs(self):
        """Gets the all_paragraphs of this DocxBody.  # noqa: E501

        All paragraphs anywhere in the document; these objects are not sequentially placed but are scatted across document  # noqa: E501

        :return: The all_paragraphs of this DocxBody.  # noqa: E501
        :rtype: list[DocxParagraph]
        """
        return self._all_paragraphs

    @all_paragraphs.setter
    def all_paragraphs(self, all_paragraphs):
        """Sets the all_paragraphs of this DocxBody.

        All paragraphs anywhere in the document; these objects are not sequentially placed but are scatted across document  # noqa: E501

        :param all_paragraphs: The all_paragraphs of this DocxBody.  # noqa: E501
        :type: list[DocxParagraph]
        """

        self._all_paragraphs = all_paragraphs

    @property
    def all_tables(self):
        """Gets the all_tables of this DocxBody.  # noqa: E501

        All tables anywhere in the document; these objects are not sequentially placed but are scatted across the document  # noqa: E501

        :return: The all_tables of this DocxBody.  # noqa: E501
        :rtype: list[DocxTable]
        """
        return self._all_tables

    @all_tables.setter
    def all_tables(self, all_tables):
        """Sets the all_tables of this DocxBody.

        All tables anywhere in the document; these objects are not sequentially placed but are scatted across the document  # noqa: E501

        :param all_tables: The all_tables of this DocxBody.  # noqa: E501
        :type: list[DocxTable]
        """

        self._all_tables = all_tables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PdfMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'title': 'str',
        'keywords': 'str',
        'subject': 'str',
        'author': 'str',
        'creator': 'str',
        'date_modified': 'datetime',
        'date_created': 'datetime',
        'page_count': 'int'
    }

    attribute_map = {
        'successful': 'Successful',
        'title': 'Title',
        'keywords': 'Keywords',
        'subject': 'Subject',
        'author': 'Author',
        'creator': 'Creator',
        'date_modified': 'DateModified',
        'date_created': 'DateCreated',
        'page_count': 'PageCount'
    }

    def __init__(self, successful=None, title=None, keywords=None, subject=None, author=None, creator=None, date_modified=None, date_created=None, page_count=None):  # noqa: E501
        """PdfMetadata - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._title = None
        self._keywords = None
        self._subject = None
        self._author = None
        self._creator = None
        self._date_modified = None
        self._date_created = None
        self._page_count = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if title is not None:
            self.title = title
        if keywords is not None:
            self.keywords = keywords
        if subject is not None:
            self.subject = subject
        if author is not None:
            self.author = author
        if creator is not None:
            self.creator = creator
        if date_modified is not None:
            self.date_modified = date_modified
        if date_created is not None:
            self.date_created = date_created
        if page_count is not None:
            self.page_count = page_count

    @property
    def successful(self):
        """Gets the successful of this PdfMetadata.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this PdfMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this PdfMetadata.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this PdfMetadata.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def title(self):
        """Gets the title of this PdfMetadata.  # noqa: E501

        Title of the document  # noqa: E501

        :return: The title of this PdfMetadata.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PdfMetadata.

        Title of the document  # noqa: E501

        :param title: The title of this PdfMetadata.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def keywords(self):
        """Gets the keywords of this PdfMetadata.  # noqa: E501

        Keywords of the document  # noqa: E501

        :return: The keywords of this PdfMetadata.  # noqa: E501
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this PdfMetadata.

        Keywords of the document  # noqa: E501

        :param keywords: The keywords of this PdfMetadata.  # noqa: E501
        :type: str
        """

        self._keywords = keywords

    @property
    def subject(self):
        """Gets the subject of this PdfMetadata.  # noqa: E501

        Subject of the document  # noqa: E501

        :return: The subject of this PdfMetadata.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this PdfMetadata.

        Subject of the document  # noqa: E501

        :param subject: The subject of this PdfMetadata.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def author(self):
        """Gets the author of this PdfMetadata.  # noqa: E501

        User name of the creator/author of the document, if available, null if not available  # noqa: E501

        :return: The author of this PdfMetadata.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this PdfMetadata.

        User name of the creator/author of the document, if available, null if not available  # noqa: E501

        :param author: The author of this PdfMetadata.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def creator(self):
        """Gets the creator of this PdfMetadata.  # noqa: E501

        Creator of the document  # noqa: E501

        :return: The creator of this PdfMetadata.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this PdfMetadata.

        Creator of the document  # noqa: E501

        :param creator: The creator of this PdfMetadata.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def date_modified(self):
        """Gets the date_modified of this PdfMetadata.  # noqa: E501

        The timestamp that the document was last modified, if available, null if not available  # noqa: E501

        :return: The date_modified of this PdfMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """Sets the date_modified of this PdfMetadata.

        The timestamp that the document was last modified, if available, null if not available  # noqa: E501

        :param date_modified: The date_modified of this PdfMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_modified = date_modified

    @property
    def date_created(self):
        """Gets the date_created of this PdfMetadata.  # noqa: E501

        The timestamp that the document was created, if available, null if not available  # noqa: E501

        :return: The date_created of this PdfMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PdfMetadata.

        The timestamp that the document was created, if available, null if not available  # noqa: E501

        :param date_created: The date_created of this PdfMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def page_count(self):
        """Gets the page_count of this PdfMetadata.  # noqa: E501

        The number of pages in the document  # noqa: E501

        :return: The page_count of this PdfMetadata.  # noqa: E501
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """Sets the page_count of this PdfMetadata.

        The number of pages in the document  # noqa: E501

        :param page_count: The page_count of this PdfMetadata.  # noqa: E501
        :type: int
        """

        self._page_count = page_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ScreenshotRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'str',
        'extra_loading_wait': 'int',
        'screenshot_width': 'int',
        'screenshot_height': 'int'
    }

    attribute_map = {
        'url': 'Url',
        'extra_loading_wait': 'ExtraLoadingWait',
        'screenshot_width': 'ScreenshotWidth',
        'screenshot_height': 'ScreenshotHeight'
    }

    def __init__(self, url=None, extra_loading_wait=None, screenshot_width=None, screenshot_height=None):  # noqa: E501
        """ScreenshotRequest - a model defined in Swagger"""  # noqa: E501

        self._url = None
        self._extra_loading_wait = None
        self._screenshot_width = None
        self._screenshot_height = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if extra_loading_wait is not None:
            self.extra_loading_wait = extra_loading_wait
        if screenshot_width is not None:
            self.screenshot_width = screenshot_width
        if screenshot_height is not None:
            self.screenshot_height = screenshot_height

    @property
    def url(self):
        """Gets the url of this ScreenshotRequest.  # noqa: E501

        URL address of the website to screenshot.  HTTP and HTTPS are both supported, as are custom ports.  # noqa: E501

        :return: The url of this ScreenshotRequest.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ScreenshotRequest.

        URL address of the website to screenshot.  HTTP and HTTPS are both supported, as are custom ports.  # noqa: E501

        :param url: The url of this ScreenshotRequest.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def extra_loading_wait(self):
        """Gets the extra_loading_wait of this ScreenshotRequest.  # noqa: E501

        Optional: Additional number of milliseconds to wait once the web page has finished loading before taking the screenshot.  Can be helpful for highly asynchronous websites.  Provide a value of 0 for the default of 5000 milliseconds (5 seconds)  # noqa: E501

        :return: The extra_loading_wait of this ScreenshotRequest.  # noqa: E501
        :rtype: int
        """
        return self._extra_loading_wait

    @extra_loading_wait.setter
    def extra_loading_wait(self, extra_loading_wait):
        """Sets the extra_loading_wait of this ScreenshotRequest.

        Optional: Additional number of milliseconds to wait once the web page has finished loading before taking the screenshot.  Can be helpful for highly asynchronous websites.  Provide a value of 0 for the default of 5000 milliseconds (5 seconds)  # noqa: E501

        :param extra_loading_wait: The extra_loading_wait of this ScreenshotRequest.  # noqa: E501
        :type: int
        """

        self._extra_loading_wait = extra_loading_wait

    @property
    def screenshot_width(self):
        """Gets the screenshot_width of this ScreenshotRequest.  # noqa: E501

        Optional: Width of the screenshot in pixels; supply 0 to default to 1280 x 1024  # noqa: E501

        :return: The screenshot_width of this ScreenshotRequest.  # noqa: E501
        :rtype: int
        """
        return self._screenshot_width

    @screenshot_width.setter
    def screenshot_width(self, screenshot_width):
        """Sets the screenshot_width of this ScreenshotRequest.

        Optional: Width of the screenshot in pixels; supply 0 to default to 1280 x 1024  # noqa: E501

        :param screenshot_width: The screenshot_width of this ScreenshotRequest.  # noqa: E501
        :type: int
        """

        self._screenshot_width = screenshot_width

    @property
    def screenshot_height(self):
        """Gets the screenshot_height of this ScreenshotRequest.  # noqa: E501

        Optional: Height of the screenshot in pixels; supply 0 to default to 1280 x 1024, supply -1 to measure the full screen height of the page and attempt to take a screen-height screenshot  # noqa: E501

        :return: The screenshot_height of this ScreenshotRequest.  # noqa: E501
        :rtype: int
        """
        return self._screenshot_height

    @screenshot_height.setter
    def screenshot_height(self, screenshot_height):
        """Sets the screenshot_height of this ScreenshotRequest.

        Optional: Height of the screenshot in pixels; supply 0 to default to 1280 x 1024, supply -1 to measure the full screen height of the page and attempt to take a screen-height screenshot  # noqa: E501

        :param screenshot_height: The screenshot_height of this ScreenshotRequest.  # noqa: E501
        :type: int
        """

        self._screenshot_height = screenshot_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScreenshotRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScreenshotRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.edit_text_api import EditTextApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestEditTextApi(unittest.TestCase):
    """EditTextApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.edit_text_api.EditTextApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_text_base64_decode(self):
        """Test case for edit_text_base64_decode

        Base 64 decode, convert base 64 string to binary content  # noqa: E501
        """
        pass

    def test_edit_text_base64_detect(self):
        """Test case for edit_text_base64_detect

        Detect, check if text string is base 64 encoded  # noqa: E501
        """
        pass

    def test_edit_text_base64_encode(self):
        """Test case for edit_text_base64_encode

        Base 64 encode, convert binary or file data to a text string  # noqa: E501
        """
        pass

    def test_edit_text_change_line_endings(self):
        """Test case for edit_text_change_line_endings

        Set, change line endings of a text file  # noqa: E501
        """
        pass

    def test_edit_text_detect_line_endings(self):
        """Test case for edit_text_detect_line_endings

        Detect line endings of a text file  # noqa: E501
        """
        pass

    def test_edit_text_remove_all_whitespace(self):
        """Test case for edit_text_remove_all_whitespace

        Remove whitespace from text string  # noqa: E501
        """
        pass

    def test_edit_text_remove_html(self):
        """Test case for edit_text_remove_html

        Remove HTML from text string  # noqa: E501
        """
        pass

    def test_edit_text_text_encoding_detect(self):
        """Test case for edit_text_text_encoding_detect

        Detect text encoding of file  # noqa: E501
        """
        pass

    def test_edit_text_trim_whitespace(self):
        """Test case for edit_text_trim_whitespace

        Trim leading and trailing whitespace from text string  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
